@@ -1,5 +1,5 @@
 #
-# $Id: OsVersion.pm,v 1.1.2.11.2.2 2006/05/31 16:49:57 gomor Exp $
+# $Id: OsVersion.pm,v 1.1.2.13.2.2 2006/06/08 18:55:42 gomor Exp $
 #
 package Net::SinFP::DB::OsVersion;
 use strict;
@@ -15,9 +15,14 @@ our @AS = qw(
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
+our $Id     = $AS[0];
+our @Fields = @AS[1..$#AS];
+
+1;
+
 =head1 NAME
 
-Net::SinFP::DB::OsVersion - OsVersion SQL table
+Net::SinFP::DB::OsVersion - OsVersion database table
 
 =head1 DESCRIPTION
 
@@ -25,11 +30,6 @@ Go to http://www.gomor.org/sinfp to know more.
 
 =cut
 
-our $Id     = qw(idOsVersion);
-our @Fields = qw(osVersion);
-
-sub getOsVersion { shift->lookupString('osVersion', idOsVersion => shift) }
-
 =head1 AUTHOR
 
 Patrice E<lt>GomoRE<gt> Auffret
@@ -42,5 +42,3 @@ You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
 =cut
-
-1;
